@@ -9,7 +9,7 @@ pub fn keysym_to_element(keysym: libc::c_uint) -> Option<VirtualKeyCode> {
         //ffi::XK_Linefeed => VirtualKeyCode::Linefeed,
         //ffi::XK_Clear => VirtualKeyCode::Clear,
         ffi::XK_Return => VirtualKeyCode::Return,
-        //ffi::XK_Pause => VirtualKeyCode::Pause,
+        ffi::XK_Pause => VirtualKeyCode::Pause,
         //ffi::XK_Scroll_Lock => VirtualKeyCode::Scroll_lock,
         //ffi::XK_Sys_Req => VirtualKeyCode::Sys_req,
         ffi::XK_Escape => VirtualKeyCode::Escape,
@@ -59,10 +59,10 @@ pub fn keysym_to_element(keysym: libc::c_uint) -> Option<VirtualKeyCode> {
         //ffi::XK_Break => VirtualKeyCode::Break,
         //ffi::XK_Mode_switch => VirtualKeyCode::Mode_switch,
         //ffi::XK_script_switch => VirtualKeyCode::Script_switch,
-        //ffi::XK_Num_Lock => VirtualKeyCode::Num_lock,
+        ffi::XK_Num_Lock => VirtualKeyCode::Numlock,
         //ffi::XK_KP_Space => VirtualKeyCode::Kp_space,
         //ffi::XK_KP_Tab => VirtualKeyCode::Kp_tab,
-        //ffi::XK_KP_Enter => VirtualKeyCode::Kp_enter,
+        ffi::XK_KP_Enter => VirtualKeyCode::NumpadEnter,
         //ffi::XK_KP_F1 => VirtualKeyCode::Kp_f1,
         //ffi::XK_KP_F2 => VirtualKeyCode::Kp_f2,
         //ffi::XK_KP_F3 => VirtualKeyCode::Kp_f3,
@@ -83,7 +83,7 @@ pub fn keysym_to_element(keysym: libc::c_uint) -> Option<VirtualKeyCode> {
         ffi::XK_KP_Equal => VirtualKeyCode::NumpadEquals,
         ffi::XK_KP_Multiply => VirtualKeyCode::NumpadMultiply,
         ffi::XK_KP_Add => VirtualKeyCode::NumpadAdd,
-        //ffi::XK_KP_Separator => VirtualKeyCode::Kp_separator,
+        ffi::XK_KP_Separator => VirtualKeyCode::NumpadComma,
         ffi::XK_KP_Subtract => VirtualKeyCode::NumpadSubtract,
         ffi::XK_KP_Decimal => VirtualKeyCode::NumpadDecimal,
         ffi::XK_KP_Divide => VirtualKeyCode::NumpadDivide,
